Documentation
¶
Index ¶
Constants ¶
const ( DefaultPrefetchDelay time.Duration = 24 * time.Hour MinimumPrefetchInterval time.Duration = 6 * time.Hour )
DO NOT DELETE IT, IT'S FUN
const CFG_Channels_Main = "main"
const CFG_Channels_SP = "sp"
Variables ¶
This section is empty.
Functions ¶
func ConfigLoad ¶
func ConfigLoad(proxy *dns.Proxy, flags *ConfigFlags) error
Types ¶
type ConfigFlags ¶
type GroupsConfig ¶
type ListenerAssociation ¶
type Main ¶
type Main struct {
LogLevel int `toml:"log_level"`
LogFile *string `toml:"log_file"`
UseSyslog bool `toml:"use_syslog"`
NetprobeTimeout int `toml:"netprobe_Timeout"`
ListenAddresses []string `toml:"listen_addresses"`
ProxyURI string `toml:"proxy_uri"`
ProxyIP string `toml:"proxy_ip"`
LocalInterface string `toml:"network_interface"`
NetprobeAddress string `toml:"netprobe_address"`
UserName string `toml:"user_name"`
Groups []GroupsConfig `toml:"groups"`
GroupsListener []ListenerAssociation `toml:"listener_association"`
}
type Source ¶
type Source struct {
// contains filtered or unexported fields
}
func NewSource ¶
func NewSource(name string, urls []string, minisignKeyStr string, cacheFile string, refreshDelay time.Duration) (source *Source, err error)
NewSource loads a new source using the given cacheFile and urls, ensuring it has a valid signature
Click to show internal directories.
Click to hide internal directories.